@@ -29,7 +29,6 @@ get_dot_data <- function(data, dots) {
 dot_names <- function(dots) unname(unlist(lapply(dots, as.character)))
 
 
-#' @importFrom dplyr quos select
 get_dplyr_dot_data <- function(x, qs) {
   if (sjmisc::is_empty(qs))
     x
@@ -40,9 +39,9 @@ get_dplyr_dot_data <- function(x, qs) {
 
 # add annotations with table summary
 # here we print out total N of cases, chi-square and significance of the table
-print.table.summary <- function(baseplot,
-                                modsum,
-                                summary.pos = "r") {
+.print.table.summary <- function(baseplot,
+                                 modsum,
+                                 summary.pos = "r") {
   if (!is.null(modsum)) {
     # add annotations with table summary
     # here we print out total N of cases, chi-square and significance of the table
@@ -72,7 +71,7 @@ print.table.summary <- function(baseplot,
 get_var_name <- function(x) {
   if (is.null(x)) return(NULL)
   # remove "data frame name"
-  dollar_pos <- regexpr("$", x, fixed = T)[1]
+  dollar_pos <- regexpr("$", x, fixed = TRUE)[1]
   if (dollar_pos != -1)
     x <- substr(x, start = dollar_pos + 1, stop = nchar(x))
 
@@ -80,147 +79,6 @@ get_var_name <- function(x) {
 }
 
 
-# Create frequency data frame of a variable
-# for sjp and sjt frq functions
-#' @importFrom sjstats weight table_values cramer phi
-#' @importFrom stats na.omit
-#' @importFrom dplyr full_join
-#' @importFrom sjmisc zap_inf
-#' @importFrom sjlabelled get_label get_labels
-create.frq.df <- function(x,
-                          wrap.labels = Inf,
-                          order.frq = "none",
-                          round.prz = 2,
-                          na.rm = FALSE,
-                          weight.by = NULL) {
-  #---------------------------------------------------
-  # zap inf and NaN
-  #---------------------------------------------------
-  x <- sjmisc::zap_inf(x)
-  #---------------------------------------------------
-  # variable with only mising?
-  #---------------------------------------------------
-  if (length(stats::na.omit(x)) == 0) {
-    mydat <- data.frame(val = NA,
-                        label = NA,
-                        frq = NA,
-                        raw.prc = NA,
-                        valid.prc = NA,
-                        cum.perc = NA,
-                        upper.ci = NA,
-                        lower.ci = NA)
-    return(invisible(structure(list(mydat = mydat))))
-  }
-  #---------------------------------------------------
-  # get value labels (if any)
-  #---------------------------------------------------
-  labels <- sjlabelled::get_labels(
-    x,
-    attr.only = T,
-    values = "n",
-    non.labelled = T
-  )
-  #---------------------------------------------------
-  # weight variable
-  #---------------------------------------------------
-  if (!is.null(weight.by)) x <- sjstats::weight(x, weight.by)
-  #---------------------------------------------------
-  # do we have a labelled vector?
-  #---------------------------------------------------
-  if (!is.null(labels)) {
-    # add rownames and values as columns
-    dat <- data_frame(n = names(labels), v = as.character(labels))
-    colnames(dat) <- c("val", "label")
-    # character vectors need to be converted with to_value
-    # to avoid NAs, but only if character is non-numeric
-    if (is.character(dat$val) && anyNA(suppressWarnings(as.numeric(dat$val))))
-      dat$val <- sjmisc::to_value(dat$val, keep.labels = F)
-    else
-      dat$val <- as.numeric(dat$val)
-    # create frequency table
-    dat2 <- data.frame(table(x, useNA = "always"))
-    colnames(dat2) <- c("val", "frq")
-    dat2$val <- sjmisc::to_value(dat2$val, keep.labels = F)
-    # join frq table and label columns
-    mydat <- suppressMessages(dplyr::full_join(dat, dat2))
-    # replace NA with 0, for proper percentages, i.e.
-    # missing values don't appear (zero counts)
-    mydat$frq <- suppressMessages(sjmisc::replace_na(mydat$frq, value = 0))
-  } else {
-    # if we have no labels, do simple frq table
-    mydat <- data.frame(table(x, useNA = "always"))
-    colnames(mydat) <- c("val", "frq")
-    # add values as label
-    mydat$label <- labels <- as.character(mydat$val)
-  }
-  #---------------------------------------------------
-  # need numeric
-  #---------------------------------------------------
-  if (is.factor(x) || is.character(x)) {
-    x <- sjmisc::to_value(x, keep.labels = F)
-  }
-  # valid values are one row less, because last row is NA row
-  valid.vals <- nrow(mydat) - 1
-  # total sum of variable, for confindence intervals
-  total_n = sum(mydat$frq)
-  rel_frq <- as.numeric(mydat$frq / total_n)
-  ci <- 1.96 * suppressWarnings(sqrt(rel_frq * (1 - rel_frq) / total_n))
-  mydat$upper.ci <- total_n * (rel_frq + ci)
-  mydat$lower.ci <- total_n * (rel_frq - ci)
-  mydat$rel.upper.ci <- rel_frq + ci
-  mydat$rel.lower.ci <- rel_frq - ci
-  # --------------------------------------------------------
-  # Order categories ascending or descending
-  # --------------------------------------------------------
-  if (!is.null(order.frq) && (order.frq == "asc" || order.frq == "desc")) {
-    ord <- order(mydat$frq[seq_len(valid.vals)], decreasing = (order.frq == "desc"))
-    mydat <- mydat[c(ord, valid.vals + 1), ]
-    labels <- labels[ord]
-  }
-  # raw percentages
-  mydat$raw.prc <- mydat$frq / sum(mydat$frq)
-  # compute valud and cumulative percentages
-  mydat$valid.prc <- c(mydat$frq[seq_len(valid.vals)] / length(stats::na.omit(x)), NA)
-  mydat$cum.prc <- c(cumsum(mydat$valid.prc[seq_len(valid.vals)]), NA)
-  # proper rounding
-  mydat$raw.prc <- 100 * round(mydat$raw.prc, round.prz + 2)
-  mydat$cum.prc <- 100 * round(mydat$cum.prc, round.prz + 2)
-  mydat$valid.prc <- 100 * round(mydat$valid.prc, round.prz + 2)
-  # -------------------------------------
-  # remove na?
-  # -------------------------------------
-  if (na.rm) {
-    mydat <- mydat[1:valid.vals, ]
-  }
-  # -------------------------------------
-  # "rename" NA values
-  # -------------------------------------
-  if (!is.null(mydat$label)) {
-    mydat$label[is.na(mydat$label)] <- "NA"
-    mydat$label[mydat$label == "<NA>"] <- "NA"
-  }
-  mydat$val <- suppressMessages(sjmisc::replace_na(mydat$val, value = max(sjmisc::to_value(mydat$val), na.rm = T) + 1))
-  # save original order
-  mydat$order <- sjmisc::to_value(mydat$val, keep.labels = F)
-  # sort for x-axis
-  mydat$val <- sort(mydat$order)
-  # -------------------------------------
-  # wrap labels?
-  # -------------------------------------
-  if (!is.infinite(wrap.labels) && !is.null(labels)) {
-    if (anyNA(labels)) labels <- stats::na.omit(labels)
-    # labels <- sjmisc::word_wrap(labels, wrap.labels)
-  }
-  # -------------------------------------
-  # return results
-  # -------------------------------------
-  class(mydat) <- "data.frame"
-  invisible(structure(list(mydat = mydat,
-                           labels = labels,
-                           minval = min(sjmisc::to_value(mydat$val, keep.labels = FALSE), na.rm = TRUE))))
-}
-
-
 # Create frequency data frame of a variable
 # for sjp and sjt frq functions
 #' @importFrom stats na.omit ftable na.pass
@@ -233,8 +91,8 @@ create.xtab.df <- function(x,
   # ------------------------------
   # convert to labels
   # ------------------------------
-  x_full <- suppressWarnings(sjmisc::to_label(x, add.non.labelled = T))
-  grp_full <- suppressWarnings(sjmisc::to_label(grp, add.non.labelled = T))
+  x_full <- suppressWarnings(sjmisc::to_label(x, add.non.labelled = TRUE))
+  grp_full <- suppressWarnings(sjmisc::to_label(grp, add.non.labelled = TRUE))
   # ------------------------------
   # create frequency crosstable. we need to convert
   # vector to labelled factor first.
@@ -331,22 +189,27 @@ get.encoding <- function(encoding, data = NULL) {
       labs <- sjlabelled::get_label(data[[1]])
       # check if vectors of data frame have
       # any valid label. else, default to utf-8
-      if (!is.null(labs) && is.character(labs))
+      if (!is.null(labs) && is.character(labs)) {
         encoding <- Encoding(sjlabelled::get_label(data[[1]]))
-      else
+      } else {
         encoding <- "UTF-8"
+      }
       # unknown encoding? default to utf-8
-      if (encoding == "unknown") encoding <- "UTF-8"
-    } else if (.Platform$OS.type == "unix")
+      if (encoding == "unknown") {
+        encoding <- "UTF-8"
+      }
+    } else if (.Platform$OS.type == "unix") {
       encoding <- "UTF-8"
-    else
+    } else {
       encoding <- "Windows-1252"
+    }
   }
   return(encoding)
 }
 
 
 # Calculate statistics of cross tabs
+#' @importFrom sjstats cramer phi table_values
 #' @importFrom stats chisq.test fisher.test xtabs
 crosstabsum <- function(x, grp, weight.by) {
   # --------------------------------------------------------
@@ -434,7 +297,6 @@ crosstabsum <- function(x, grp, weight.by) {
 #         (prcomp(myData...))
 # - factors: the amount of factors. can be calculated from the
 #            below function "factorcount"
-#' @importFrom stats varimax
 varimaxrota <- function(data, factors) {
   # Faktorladungen berechnen
   # Die Faktorladungen erhält man durch Multiplikation der Eigenvektoren
